translate.storage.ts2

Package translate :: Package storage :: Module ts2 |
[hide private]
[frames] | no frames]

# Module ts2

source code

Module for handling Qt linguist (.ts) files.

This will eventually replace the older ts.py which only supports the older format. While converters haven't been updated to use this module, we retain both.

TS file format 4.3, http://doc.trolltech.com/4.5/linguist-ts-file-format.html>, Example, Plurals forms

Specification of the valid variable entries, 2

Classes | [hide private]
| tsunit A single term in the xliff file.
| tsfile Class representing a XLIFF file store.

Variables | [hide private]
| NPLURALS = `{'jp': 1, 'en': 2, 'fr': 2, 'lv': 3, 'ga': 3, 'cs':`...``

Imports: base, lisa, general, StringElem, multistring, data, etree

Variables Details | [hide private]

  ### NPLURALS Value:
      {'jp': 1, 'en': 2, 'fr': 2, 'lv': 3, 'ga': 3, 'cs': 3, 'sk': 3, 'mk':
      3, 'lt': 3, 'ru': 3, 'pl': 3, 'ro': 3, 'sl': 4, 'mt': 4, 'cy': 5, 'ar'
      : 6,}